@@ -107,7 +107,6 @@ sub poster_config { # posting to CoreSmokeDB
             'LWP::UserAgent' => [
                 ua_timeout(),
             ],
-            'HTTP::Lite' => [],
             'HTTP::Tiny' => [],
             'curl' => [
                 curlbin(),
@@ -195,6 +194,7 @@ sub runsmoke_config { # runsmoke.pl
             w32args(),
             w32cc(),
             w32make(),
+            pass_option(),
         ],
     );
 }
@@ -654,7 +654,7 @@ sub poster {
     return $opt->new(
         name     => 'poster',
         option   => '=s',
-        allow    => [qw/LWP::UserAgent HTTP::Lite HTTP::Tiny curl/],
+        allow    => [qw/LWP::UserAgent HTTP::Tiny curl/],
         default  => 'LWP::UserAgent',
         helptext => "The type of HTTP post system to use.",
     );
@@ -898,7 +898,7 @@ sub w32args {
 sub w32cc {
     return $opt->new(
         name => 'w32cc',
-        opt => '=s',
+        option => '=s',
         helptext => "The compiler on MSWin32.",
     );
 }
@@ -906,12 +906,29 @@ sub w32cc {
 sub w32make {
     return $opt->new(
         name => 'w32make',
-        opt => '=s',
+        option => '=s',
         default => 'dmake',
         helptext => "The make program on MSWin32.",
     );
 }
 
+sub pass_option {
+    return $opt->new(
+        name => 'pass_option',
+        option => 'pass-option|p=s@',
+        default => [],
+        allow => sub {
+            my ($list) = @_;
+            return unless ref($list) eq 'ARRAY';
+            for my $to_pass (@$list) {
+                return unless $to_pass =~ m{^ - [DUA] .+ $}x;
+            }
+            return 1;
+        },
+        helptext => 'Pass these options to Configure.',
+    );
+}
+
 1;
 
 =head1 COPYRIGHT
